module Intra
  module Authenticatable
    def self.included(base)
      base.extend ClassMethods
      base.class_eval do
        def reset_remember_token!
          update remember_token: SecureRandom.hex
        end
      end
    end

    module ClassMethods
      # process the omniauth hash sent from provider to /oauth/:provider/callback
      # returns an instance of a User
      def authenticate(hash)
        params = {
          uuid: hash[:provider] + '|' + hash[:uid],
          email: hash.dig(:info, :email).presence || hash.dig(:info, :name),
          image_url: hash.dig(:info, :image),
          remember_token: SecureRandom.hex
        }
        Intra.logger.debug 'omniauth response to params=' + params.to_s
        user = find_by uuid: params[:uuid]
        if user
          user.update! params
        else
          user = create! params
        end
        user
      end
    end
  end
end
