module Intra
  module Authentication
    def self.included(base)
      base.class_eval do
        if respond_to?(:helper_method)
          helper_method :current_user, :signed_in?, :signed_out?
        end

        private(
          :authenticate!,
          :current_user,
          :handle_unverified_request,
          :sign_in,
          :sign_out,
          :signed_in?,
          :signed_out?
        )
      end
    end

    def authenticate!
      Intra.logger.debug 'Intra::Authentication authenticate!'
      redirect_to Intra.sign_in_path unless signed_in?
    end

    def current_user
      intra_session&.current_user
    end

    def sign_in(hash)
      Intra.logger.debug 'Intra::Authentication sign_in'
      user = Intra.user_class.constantize.authenticate(hash)
      intra_session.sign_in user
    end

    def sign_out
      Intra.logger.debug 'Intra::Authentication sign_out'
      intra_session&.sign_out
    end

    def signed_in?
      intra_session&.signed_in?
    end

    def signed_out?
      intra_session&.signed_out?
    end

    def handle_unverified_request
      super
      sign_out
    end

    def intra_session
      request.env[:intra]
    end
  end
end
