namespace :intra do
  desc 'Install Intra initializer and migration file'
  task :install do
    filename = 'config/initializers/intra.rb'
    File.write filename, INITIALIZER
    puts 'Added initializer to ' + filename
    time = Time.now.strftime("%Y%m%d%H%M%S")
    filename = "db/migrate/#{time}_create_users.rb"
    File.write filename, MIGRATION
    puts 'Added migration to ' + filename
    puts 'Done'
  end

  INITIALIZER = <<-RUBY
Intra.logger           = Rails.logger
OmniAuth.config.logger = Rails.logger

GOOGLE_OPTIONS = {
  name: 'google',
  prompt: 'select_account',
  image_aspect_ratio: 'square',
  image_size: 50,
  hd: 'mydomain.com'
}

Rails.application.config.middleware.use OmniAuth::Builder do
  provider :developer unless Rails.env.production?
  provider :google_oauth2,
    ENV['GOOGLE_CLIENT_ID'],
    ENV['GOOGLE_CLIENT_SECRET'],
    GOOGLE_OPTIONS
end
RUBY

  MIGRATION = <<-RUBY
class CreateUsers < ActiveRecord::Migration[5.2]
  def change
    create_table :users do |t|
      t.string :uuid, null: false
      t.string :remember_token
      t.string :email
      t.string :first_name
      t.string :last_name
      t.string :image_url

      t.timestamps
    end
  end
end
RUBY
end
